@@ -3,7 +3,7 @@
 package App::abgrep;
 
 our $DATE = '2018-01-29'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -37,13 +37,17 @@ _
     },
     output_code => sub {
         my %args = @_;
-        my $files = $args{files};
         my ($fh, $file);
 
+        my @files = @{ $args{files} // [] };
+        if ($args{regexps} && @{ $args{regexps} }) {
+            unshift @files, delete $args{pattern};
+        }
+
         my $show_label = 0;
-        if (!$files || !@$files) {
+        if (!@files) {
             $fh = \*STDIN;
-        } elsif (@$files > 1) {
+        } elsif (@files > 1) {
             $show_label = 1;
         }
 
@@ -51,8 +55,8 @@ _
           READ_LINE:
             {
                 if (!defined $fh) {
-                    return unless @$files;
-                    $file = shift @$files;
+                    return unless @files;
+                    $file = shift @files;
                     log_trace "Opening $file ...";
                     open $fh, "<", $file or do {
                         warn "abgrep: Can't open '$file': $!, skipped\n";
@@ -90,7 +94,7 @@ App::abgrep - Print lines matching a pattern
 
 =head1 VERSION
 
-This document describes version 0.002 of App::abgrep (from Perl distribution App-abgrep), released on 2018-01-29.
+This document describes version 0.003 of App::abgrep (from Perl distribution App-abgrep), released on 2018-01-29.
 
 =head1 FUNCTIONS
 
@@ -112,6 +116,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<all> => I<true>
+
+Require all patterns to match, instead of just one.
+
 =item * B<color> => I<str>
 
 =item * B<count> => I<true>
@@ -128,10 +136,12 @@ Invert the sense of matching.
 
 =item * B<line_number> => I<true>
 
-=item * B<pattern>* => I<re>
+=item * B<pattern> => I<re>
 
 =item * B<quiet> => I<true>
 
+=item * B<regexps> => I<array[re]>
+
 =back
 
 Returns an enveloped result (an array).
